@@ -32,17 +32,17 @@ __all__ = ("ListRepositoryAssociationsPaginator",)
 
 class ListRepositoryAssociationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
+    [Paginator.ListRepositoryAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations)
     """
 
     def paginate(
         self,
-        ProviderTypes: List[Literal["CodeCommit", "GitHub"]] = None,
+        ProviderTypes: List[Literal["CodeCommit", "GitHub", "Bitbucket"]] = None,
         States: List[Literal["Associated", "Associating", "Failed", "Disassociating"]] = None,
         Names: List[str] = None,
         Owners: List[str] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListRepositoryAssociationsResponseTypeDef]:
         """
-        [ListRepositoryAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.4/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
+        [ListRepositoryAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/codeguru-reviewer.html#CodeGuruReviewer.Paginator.ListRepositoryAssociations.paginate)
         """
